@@ -14,7 +14,7 @@
 # limitations under the License.
 
 import json
-import mock
+from unittest import mock
 
 from zaqarclient import errors
 from zaqarclient.queues import client
